@@ -1,6 +1,6 @@
 package Statocles::App::Blog;
 # ABSTRACT: A blog application
-$Statocles::App::Blog::VERSION = '0.032';
+$Statocles::App::Blog::VERSION = '0.033';
 use Statocles::Base 'Class';
 use Getopt::Long qw( GetOptionsFromArray );
 use Statocles::Store::File;
@@ -125,10 +125,13 @@ ENDHELP
 
         if ( $ENV{EDITOR} ) {
             # I can see no good way to test this automatically
-            my $tmp_store = Statocles::Store::File->new( path => Path::Tiny->tempdir );
-            my $tmp_path = $tmp_store->write_document( new_post => \%doc );
+            my $slug = lc $title || "new post";
+            $slug =~ s/\s+/-/g;
+            my $path = Path::Tiny->new( @date_parts, "$slug.markdown" );
+            my $tmp_path = $self->store->write_document( $path => \%doc );
             system $ENV{EDITOR}, $tmp_path;
-            %doc = %{ $tmp_store->read_document( 'new_post' ) };
+            %doc = %{ $self->store->read_document( $path ) };
+            $self->store->path->child( $path )->remove;
             $title = $doc{title};
         }
 
@@ -356,7 +359,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 DESCRIPTION
 
