@@ -1,9 +1,9 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.032';
+$Statocles::Command::VERSION = '0.033';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
-use Getopt::Long qw( GetOptionsFromArray );
+use Getopt::Long qw( GetOptionsFromArray :config pass_through );
 use Pod::Usage::Return qw( pod2usage );
 use File::Share qw( dist_dir );
 use File::Copy::Recursive qw( dircopy );
@@ -281,7 +281,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
